@@ -12,6 +12,10 @@
 {-# LANGUAGE DataKinds #-}
 #endif
 
+#if __GLASGOW_HASKELL__ >= 800
+{-# LANGUAGE DeriveLift #-}
+#endif
+
 #ifndef MIN_VERSION_vector
 #define MIN_VERSION_vector(x,y,z) 1
 #endif
@@ -88,6 +92,9 @@ import GHC.Generics (Generic)
 #if __GLASGOW_HASKELL__ >= 706
 import GHC.Generics (Generic1)
 #endif
+#if __GLASGOW_HASKELL__ >= 800
+import Language.Haskell.TH.Syntax (Lift)
+#endif
 import Linear.Epsilon
 import Linear.Metric
 #if __GLASGOW_HASKELL__ >= 707
@@ -107,6 +114,9 @@ data Plucker a = Plucker !a !a !a !a !a !a deriving (Eq,Ord,Show,Read
 #endif
 #if __GLASGOW_HASKELL__ >= 706
                                                     ,Generic1
+#endif
+#if __GLASGOW_HASKELL__ >= 800
+                                                    ,Lift
 #endif
                                                     )
 
