@@ -1,4 +1,5 @@
 {-# LANGUAGE CPP #-}
+{-# LANGUAGE TypeOperators #-}
 {-# LANGUAGE KindSignatures #-}
 {-# LANGUAGE ScopedTypeVariables #-}
 {-# LANGUAGE GeneralizedNewtypeDeriving #-}
@@ -19,6 +20,10 @@
 {-# LANGUAGE Trustworthy #-}
 {-# LANGUAGE DeriveGeneric #-}
 
+#ifndef MIN_VERSION_hashable
+#define MIN_VERSION_hashable(x,y,z) 1
+#endif
+
 #ifndef MIN_VERSION_reflection
 #define MIN_VERSION_reflection(x,y,z) 1
 #endif
@@ -78,6 +83,10 @@ import Data.Foldable as Foldable
 import Data.Functor.Bind
 import Data.Functor.Classes
 import Data.Functor.Rep as Rep
+import Data.Hashable
+#if (MIN_VERSION_hashable(1,2,5))
+import Data.Hashable.Lifted
+#endif
 #if __GLASGOW_HASKELL__ < 708
 import Data.Proxy
 #endif
@@ -359,6 +368,19 @@ instance Dim n => Distributive (V n) where
   distribute f = V $ V.generate (reflectDim (Proxy :: Proxy n)) $ \i -> fmap (\(V v) -> unsafeIndex v i) f
   {-# INLINE distribute #-}
 
+instance Hashable a => Hashable (V n a) where
+  hashWithSalt s0 (V v) =
+    V.foldl' (\s a -> s `hashWithSalt` a) s0 v
+      `hashWithSalt` V.length v
+
+#if (MIN_VERSION_hashable(1,2,5))
+instance Dim n => Hashable1 (V n) where
+  liftHashWithSalt h s0 (V v) =
+    V.foldl' (\s a -> h s a) s0 v
+      `hashWithSalt` V.length v
+  {-# INLINE liftHashWithSalt #-}
+#endif
+
 instance (Dim n, Storable a) => Storable (V n a) where
   sizeOf _ = reflectDim (Proxy :: Proxy n) * sizeOf (undefined:: a)
   {-# INLINE sizeOf #-}
@@ -445,9 +467,9 @@ type instance Index (V n a) = Int
 type instance IxValue (V n a) = a
 
 instance Ixed (V n a) where
-  ix i f (V as)
-     | i < 0 || i >= V.length as = pure $ V as
-     | otherwise = f (as ! i) <&> \a -> V $ as V.// [(i, a)]
+  ix i f v@(V as)
+     | i < 0 || i >= V.length as = pure v
+     | otherwise = vLens i f v
   {-# INLINE ix #-}
 
 instance Dim n => MonadZip (V n) where
@@ -583,3 +605,29 @@ instance (Dim n, U.Unbox a) => G.Vector U.Vector (V n a) where
   basicUnsafeIndexM (V_VN _ v) i =
     liftM V $ V.generateM d (\j -> G.basicUnsafeIndexM v (d*i+j))
     where d = reflectDim (Proxy :: Proxy n)
+
+vLens :: Int -> Lens' (V n a) a
+vLens i = \f (V v) -> f (v V.! i) <&> \a -> V (v V.// [(i, a)])
+{-# INLINE vLens #-}
+
+#ifdef USE_TYPE_LITS
+instance ( 1 <= n) => Field1  (V n a) (V n a) a a where _1  = vLens  0
+instance ( 2 <= n) => Field2  (V n a) (V n a) a a where _2  = vLens  1
+instance ( 3 <= n) => Field3  (V n a) (V n a) a a where _3  = vLens  2
+instance ( 4 <= n) => Field4  (V n a) (V n a) a a where _4  = vLens  3
+instance ( 5 <= n) => Field5  (V n a) (V n a) a a where _5  = vLens  4
+instance ( 6 <= n) => Field6  (V n a) (V n a) a a where _6  = vLens  5
+instance ( 7 <= n) => Field7  (V n a) (V n a) a a where _7  = vLens  6
+instance ( 8 <= n) => Field8  (V n a) (V n a) a a where _8  = vLens  7
+instance ( 9 <= n) => Field9  (V n a) (V n a) a a where _9  = vLens  8
+instance (10 <= n) => Field10 (V n a) (V n a) a a where _10 = vLens  9
+instance (11 <= n) => Field11 (V n a) (V n a) a a where _11 = vLens 10
+instance (12 <= n) => Field12 (V n a) (V n a) a a where _12 = vLens 11
+instance (13 <= n) => Field13 (V n a) (V n a) a a where _13 = vLens 12
+instance (14 <= n) => Field14 (V n a) (V n a) a a where _14 = vLens 13
+instance (15 <= n) => Field15 (V n a) (V n a) a a where _15 = vLens 14
+instance (16 <= n) => Field16 (V n a) (V n a) a a where _16 = vLens 15
+instance (17 <= n) => Field17 (V n a) (V n a) a a where _17 = vLens 16
+instance (18 <= n) => Field18 (V n a) (V n a) a a where _18 = vLens 17
+instance (19 <= n) => Field19 (V n a) (V n a) a a where _19 = vLens 18
+#endif
